@@ -23,12 +23,16 @@ from .utils import (
     validate_port,
     validate_ip,
     validate_protocol,
+    UseTlsAdapter,
 )
 
 
 requests.packages.urllib3.disable_warnings()
 log = logging.getLogger(__name__)
 
+tls_session = requests.Session()
+tls_session.mount("https://", UseTlsAdapter())
+
 
 class HttpClient(object):
     """Client that performs HTTP requests."""
@@ -61,15 +65,13 @@ class HttpClient(object):
         try:
             if file is not None:
                 with open(file, 'rb') as payload:
-                    response = requests.request(http_method, cmd_url,
-                                                params=parameters,
-                                                verify=False,
-                                                data=payload)
+                    response = tls_session.request(http_method, cmd_url,
+                                                   params=parameters,
+                                                   verify=False, data=payload)
             else:
-                response = requests.request(http_method, cmd_url,
-                                            params=parameters,
-                                            timeout=5,
-                                            verify=False)
+                response = tls_session.request(http_method, cmd_url,
+                                               params=parameters,
+                                               timeout=5, verify=False)
             if 400 < response.status_code < 500:
                 raise KempTechApiException(msg=response.text)
             else:
@@ -238,7 +240,7 @@ class LoadMaster(HttpClient):
                                                            ip=self.ip_address,
                                                            port=self.port)
         try:
-            requests.get(url, verify=False, timeout=1)
+            tls_session.get(url, verify=False, timeout=1)
             return True
         except exceptions.RequestException:
             return False
